==> component-tbk-order-2.0.0-20200506.055645-1-sources.jar: com/bxm/component/tbk/order/timer/DuomaiMeituanOrderSyncDaysTask.java <==
package com.bxm.component.tbk.order.timer;


import com.bxm.component.tbk.order.config.OrderTimerConfigProperties;
import com.bxm.component.tbk.order.service.MeituanTakeOutOrderService;
import com.bxm.newidea.component.schedule.task.AbstractCronTask;
import com.xxl.job.core.biz.model.ReturnT;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

/**
 * 美团订单每日同步定时任务
 * @Author: Gonzo
 * @date  2020-03-26 16:35
 * @since 1.6.1
 */
@Component
@Slf4j
@AllArgsConstructor
public class DuomaiMeituanOrderSyncDaysTask extends AbstractCronTask<String> {

    private final MeituanTakeOutOrderService meituanTakeOutOrderService;

    private final OrderTimerConfigProperties orderTimerConfigProperties;

    @Override
    protected ReturnT<String> service(String s) {
        log.info("执行任务: {} 开始", taskName());
        try {
            meituanTakeOutOrderService.syncOrderOneDayOnce();
        } catch(Exception e) {
            log.error("执行任务: {} 出错", taskName(), e);
            return ReturnT.FAIL;
        }

        log.info("执行任务: {} 结束", taskName());
        return ReturnT.SUCCESS;
    }

    @Override
    public String taskName() {
        return "多麦联盟美团订单日拉取";
    }

    @Override
    public String cron() {
        if (log.isDebugEnabled()) {
            log.debug("{}: {}", taskName(), orderTimerConfigProperties.getDuomaiMeituanOrderSyncDaysCron());
        }

        return orderTimerConfigProperties.getDuomaiMeituanOrderSyncDaysCron();
    }
}

==> component-tbk-order-2.0.0-20200514.015456-8-sources.jar: com/bxm/component/tbk/order/timer/DuomaiMeituanOrderSyncDaysTask.java <==
package com.bxm.component.tbk.order.timer;


import com.bxm.component.tbk.order.config.OrderTimerConfigProperties;
import com.bxm.component.tbk.order.config.TbkOpenOrderProperties;
import com.bxm.component.tbk.order.service.MeituanTakeOutOrderService;
import com.bxm.newidea.component.schedule.task.AbstractCronTask;
import com.xxl.job.core.biz.model.ReturnT;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

/**
 * 美团订单每日同步定时任务
 * @Author: Gonzo
 * @date  2020-03-26 16:35
 * @since 1.6.1
 */
@Component
@Slf4j
@AllArgsConstructor
public class DuomaiMeituanOrderSyncDaysTask extends AbstractCronTask<String> {

    private final MeituanTakeOutOrderService meituanTakeOutOrderService;

    private final OrderTimerConfigProperties orderTimerConfigProperties;

    private final TbkOpenOrderProperties tbkOpenOrderProperties;

    @Override
    protected ReturnT<String> service(String s) {
        log.info("执行任务: {} 开始", taskName());
        try {
            meituanTakeOutOrderService.syncOrderOneDayOnce();
        } catch(Exception e) {
            log.error("执行任务: {} 出错", taskName(), e);
            return ReturnT.FAIL;
        }

        log.info("执行任务: {} 结束", taskName());
        return ReturnT.SUCCESS;
    }

    @Override
    public String taskName() {
        return "多麦联盟美团订单日拉取" + tbkOpenOrderProperties.getSite();
    }

    @Override
    public String cron() {
        if (log.isDebugEnabled()) {
            log.debug("{}: {}", taskName(), orderTimerConfigProperties.getDuomaiMeituanOrderSyncDaysCron());
        }

        return orderTimerConfigProperties.getDuomaiMeituanOrderSyncDaysCron();
    }
}
